# We need the stubs used for SystemdService tests
require_relative "../../systemd/test/test_helper"

require_relative "../../../test/test_helper.rb"
